% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/context_methylation_functions.r
\name{GetSingleMolMethMat}
\alias{GetSingleMolMethMat}
\title{Get Single Molecule methylation matrix}
\usage{
GetSingleMolMethMat(QuasRprj, range, sample)
}
\arguments{
\item{QuasRprj}{QuasR project object as returned by calling the QuasR function qAling on previously aligned data}

\item{range}{GenimocRange representing the genomic region of interest}

\item{sample}{One of the sample names as reported in the SampleName field of the QuasR pointer file provided to qAlign. N.b. all the files with the passed sample name will be used to call methylation}
}
\value{
Single molecule methylation matrix (all Cytosines)
}
\description{
Used internally as the first step in CallContextMethylation
}
\examples{
Qinput = paste0(tempdir(), "/NRF1Pair_Qinput.txt")
library(BSgenome.Mmusculus.UCSC.mm10)

if(file.exists(Qinput)){
    QuasRprj = GetQuasRprj(Qinput, BSgenome.Mmusculus.UCSC.mm10)

    sample = readr::read_delim(Qinput, delim = "\t")$SampleName
    range = GRanges(seqnames = "chr6", ranges = IRanges(start = 88106000, end = 88106500), strand = "*")

    MethSM = GetSingleMolMethMat(QuasRprj, range, sample)
}

}
